@@ -1,7 +1,7 @@
 """
 Type annotations for proton service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_proton/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_proton/literals/)
 
 Usage::
 
@@ -59,7 +59,9 @@ __all__ = (
     "SyncTypeType",
     "TemplateTypeType",
     "TemplateVersionStatusType",
+    "ProtonServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -136,6 +138,7 @@ TemplateTypeType = Literal["ENVIRONMENT", "SERVICE"]
 TemplateVersionStatusType = Literal[
     "DRAFT", "PUBLISHED", "REGISTRATION_FAILED", "REGISTRATION_IN_PROGRESS"
 ]
+ProtonServiceName = Literal["proton"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -167,6 +170,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -253,6 +257,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -289,6 +294,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -437,6 +443,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_environment_account_connections",
     "list_environment_outputs",
